% 
% Setup
% Define model parameters 
% then define structures to pass parameters to functions
%

% Constants
beta=0.95;          % discount factor
d=0.5;              % marginal investment cost
kappa=35;           % sunk entry cost
xe=10;              % entry state
fix_n=0;            % fix_n ~= 0 indicates number of firms in industry with 
                    % with fixed number of firms (no entry/no exit)
                    % fix_n=0 if industy with entry and exit
entryproc=1;        % Indicates entry process
                    % =1 if Poisson, =2 if constant number of entrants   


% Transition probabilities
% transition model in Weintraub, Benkard, and Van Roy (2005)
a=3;                % parameter on succesful investment
delta=0.7;          % probability of depreciation

% Sell-off value
K=10;               % Average sell-off value
if(fix_n ~= 0)
    K=1.0e-100;     % if fixed number of firms, sell-off value is small (no exit) 
end


% Parameters profit function in Weintraub, Benkard, and Van Roy (2005)
% price competition with product differentiation
% logit demand system
% constant marginal cost of production
m=50;              % market size
Y=1;                % average income
theta1=1.0;         % quality weight consumers' utility function
theta2=0.5;         % composite good weight consumers' utility function
psi=1;              % scaling parameter
utout=0;            % utility outside good
c=0.5;              % marginal cost of production
p0=(Y+theta2*c)/(1+theta2);     % initial condition for solving price game


% Initial conditions
xmax0=30;                  % initial condition for max acheivable state 
                           % each firm state is an element of {0,...,xmax-1}   
lambda10=1.7;              % initial condition entry rate lambda lowest value
lambda20=2.3;              % initial condition entry rate lambda highest value 
iota0=ones(xmax0,1);       % initial condition investment
rho0=ones(xmax0,1)*kappa;  % initial condition exit strategy (cut-off value)


% Parameters for program controls
% precisions and tolerances

% CONTROL PARAMETERS FOR COMPUTING OE
TOL_condnum=10^-20;  % tolerance condition number for matrix inversion
TOL_freq=200;        % tolerance convergence infinite sum to compute expected frequency
                     % TOL_freq is number of periods to sum when interest rate equals 5%
                     % program (expstate.m) sets tolerance
                     % proportionally to interest rate
TOL_valueit=10^-8;   % tolerance max difference value functions in value iteration
TOL_probs=10^-5;     % tolerance difference probs. when computing fixed point
                     % strategy given entry rate
NMAX_strats=200;     % max number of iterations when computing fixed point
                     % strategy given entry rate    
expupdatestrat=2/3;  % exponent for smooth update for strategies  
                     % when computing fixed point strategy given entry rate
TOL_freqxmax=10^-5;  % if entry and exit: tolerance expected number of visits at xmax 
                     % if no entry/no exit: tolerance prob. of being at xmax under invariant 
                     % distribution of Markov chain that describes evolution of one firm
xmaxupdate=5;       % updating xmax = xmax + xmaxupdate
FACTOR_lambda=0.3;   % Multiply entry rate lambda initial interval
FACTOR_lambdaignore=0.1;   % Multiply entry rate lambda initial interval for computing OE with full-fledge profits
TOL_zeroprof=0.05;         % tolerance zero profit condition

% CONTROL PARAMETERS FOR COMPUTING BOUNDS
kmax_bound=1;       % xmax_bound=xmax*kmax_bound, where {0,...,xmax_bound-1} is augmented 
                    % state space to compute bounds.    
TOL_precbounds=0.1; % tolerance relative precision when simulating bounds
TOL_precV=0.01;     % tolerance relative precision when simulating expected value function
NMAX_bound=10000;      % maximum number of iterations to compute bounds
NMIN_bound=100;     % minimum number of iterations to compute bounds
ini_x_bound=xe;     % starting state dependent improved bound computed for states
dis_x_bound=5;      % {ini_x_bound,ini_x_bound+dis_x_bound,...,xmax-dis_x_bound} 
defmaxbound=4*m*Y/(1-beta)+10*K; % maximum value of bound to use as default
dis_opt_bound=5;    % optimization step for improved bound  
TOL_time_cons_entr=1000;    % maximum number of periods to consider when sampling state
                            % in case constant number of entrants 
TOL_sample_cons_entr=10^-3; % tolerance prob. being in industry when sampling state
                            % in case constant number of entrants 


% Define structures to pass parameters to functions

constants.beta=beta;
constants.d=d;
constants.kappa=kappa;
constants.xe=xe;
constants.fix_n=fix_n;
constants.entryproc=entryproc;

transition.a=a;
transition.delta=delta;
transition.K=K;

profpar.m=m;
profpar.Y=Y;
profpar.theta1=theta1;
profpar.theta2=theta2;
profpar.psi=psi;
profpar.utout=utout;
profpar.c=c;
profpar.p0=p0;

initial.xmax0=xmax0;
initial.lambda10=lambda10;
initial.lambda20=lambda20;
initial.iota0=iota0;
initial.rho0=rho0;

control.TOL_condnum=TOL_condnum;
control.TOL_freq=TOL_freq;
control.TOL_valueit=TOL_valueit;
control.TOL_probs=TOL_probs;
control.NMAX_strats=NMAX_strats;
control.TOL_freqxmax=TOL_freqxmax;
control.expupdatestrat=expupdatestrat;
control.xmaxupdate=xmaxupdate;    
control.FACTOR_lambda=FACTOR_lambda;
control.FACTOR_lambdaignore=FACTOR_lambdaignore;
control.TOL_zeroprof=TOL_zeroprof;
control.kmax_bound=kmax_bound;
control.TOL_precbounds=TOL_precbounds;
control.TOL_precV=TOL_precV;
control.NMAX_bound=NMAX_bound;
control.NMIN_bound=NMIN_bound;
control.ini_x_bound=ini_x_bound;
control.dis_x_bound=dis_x_bound;
control.defmaxbound=defmaxbound;
control.dis_opt_bound=dis_opt_bound;
control.TOL_time_cons_entr=TOL_time_cons_entr;
control.TOL_sample_cons_entr=TOL_sample_cons_entr;
